"use strict";

exports.__esModule = true;
exports.Carousel = void 0;

var React = _interopRequireWildcard(require("react"));

var _framerMotion = require("framer-motion");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { "default": obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var containerStyle = {
  position: "relative",
  width: "100%",
  height: "100%",
  overflowX: "hidden",
  display: "flex"
};
var pageStyle = {
  width: "100%",
  height: "100%",
  display: "inline-block",
  flex: "none"
};
var transition = {
  type: "spring",
  bounce: 0
};
var Contaier = /*#__PURE__*/React.forwardRef(function (props, ref) {
  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    style: containerStyle
  }, props.children);
});

var Slider = function Slider(_ref) {
  var x = _ref.x,
      i = _ref.i,
      onDragEnd = _ref.onDragEnd,
      children = _ref.children;
  return /*#__PURE__*/React.createElement(_framerMotion.motion.div, {
    style: _extends({}, pageStyle, {
      x: x,
      left: i * 100 + "%",
      right: i * 100 + "%"
    }),
    drag: "x",
    dragElastic: 0.3,
    onDragEnd: onDragEnd
  }, children);
};

var baseArrowStyle = {
  position: "absolute",
  width: "50px",
  height: "50px",
  backgroundColor: "rgba(0,0,0,0.5)",
  top: "50%",
  transform: "translateY(-50%)",
  borderRadius: "50%",
  color: "#fff",
  fontSize: "20px",
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  cursor: "pointer"
};

var Arrow = function Arrow(_ref2) {
  var _ref2$left = _ref2.left,
      left = _ref2$left === void 0 ? false : _ref2$left,
      children = _ref2.children,
      onClick = _ref2.onClick;
  return /*#__PURE__*/React.createElement("div", {
    onClick: onClick,
    style: _extends({}, baseArrowStyle, {
      left: left ? "20px" : "initial",
      right: !left ? "10px" : "initial"
    })
  }, children);
};

var Carousel = function Carousel(_ref3) {
  var children = _ref3.children,
      renderArrowLeft = _ref3.renderArrowLeft,
      renderArrowRight = _ref3.renderArrowRight;
  var x = (0, _framerMotion.useMotionValue)(0);
  var containerRef = React.useRef(null);

  var _React$useState = React.useState(0),
      index = _React$useState[0],
      setIndex = _React$useState[1];

  var calculateNewX = function calculateNewX() {
    var _containerRef$current;

    return -index * (((_containerRef$current = containerRef.current) == null ? void 0 : _containerRef$current.clientWidth) || 0);
  };

  var handleEndDrag = function handleEndDrag(e, dragProps) {
    var _containerRef$current2;

    var clientWidth = ((_containerRef$current2 = containerRef.current) == null ? void 0 : _containerRef$current2.clientWidth) || 0;
    var offset = dragProps.offset;

    if (offset.x > clientWidth / 4) {
      handlePrev();
    } else if (offset.x < -clientWidth / 4) {
      handleNext();
    } else {
      (0, _framerMotion.animate)(x, calculateNewX(), transition);
    }
  };

  var childrens = React.Children.toArray(children);

  var handleNext = function handleNext() {
    setIndex(index + 1 === childrens.length ? index : index + 1);
  };

  var handlePrev = function handlePrev() {
    setIndex(index - 1 < 0 ? 0 : index - 1);
  };

  React.useEffect(function () {
    var controls = (0, _framerMotion.animate)(x, calculateNewX(), transition);
    return controls.stop;
  }, [index]);
  return /*#__PURE__*/React.createElement(Contaier, {
    ref: containerRef
  }, childrens.map(function (child, i) {
    return /*#__PURE__*/React.createElement(Slider, {
      onDragEnd: handleEndDrag,
      x: x,
      i: i
    }, child);
  }), renderArrowLeft ? renderArrowLeft({
    handlePrev: handlePrev,
    activeIndex: index
  }) : /*#__PURE__*/React.createElement(Arrow, {
    left: true,
    onClick: handlePrev
  }, "\u2190"), renderArrowRight ? renderArrowRight({
    handleNext: handleNext,
    activeIndex: index
  }) : /*#__PURE__*/React.createElement(Arrow, {
    onClick: handleNext
  }, "\u2192"));
};

exports.Carousel = Carousel;